package com.huoran.iasf.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.huoran.iasf.common.aop.annotation.NoRepeatSubmit;
import com.huoran.iasf.common.utils.Constant;
import com.huoran.iasf.entity.*;
import com.huoran.iasf.service.*;
import com.huoran.iasf.vo.req.ColumnWeightReqVO;
import com.huoran.iasf.vo.req.PaginationColumnReqVO;
import com.huoran.iasf.vo.resp.SortColumnRespVO;
import io.swagger.annotations.*;
import com.huoran.iasf.common.utils.R;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.Api;
import org.springframework.web.bind.annotation.RequestParam;
import io.swagger.annotations.ApiOperation;

import javax.validation.Valid;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;


/**
 * @描述：栏目基础信息控制类
 * @作者: Rong
 * @日期: 2022-08-01
 */
@RestController
@RequestMapping("/sysColumn")
@Api(value = "栏目基础信息:SysColumnController", tags = "R-栏目管理")
public class SysColumnController {

    @Autowired
    public SysColumnService service;

    @Autowired
    public SysContentService contentService;

    @Autowired
    public SysTemplateService templateService;

    @Autowired
    public SysTemplateStyleService styleService;

    @Autowired
    public SysTemplateStyleConfigurationService templateStyleConfigurationService;

    @Autowired
    public SysFilesService sysFilesService;

    @PostMapping("/listWithTree")
    @ApiOperation(value = "栏目树结构", response = SysColumn.class)
    public R listWithTree(@RequestBody @Validated PaginationColumnReqVO sysColumn) {
        return R.success(service.listWithTree(sysColumn));
    }

    @PostMapping("/listWithTreeMenuVisible")
    @ApiOperation(value = "栏目树结构(前台可见，只展示试单可见的栏目)", response = SysColumn.class)
    public R listWithTreeMenuVisible(@RequestBody @Validated PaginationColumnReqVO sysColumn) {
        return R.success(service.listWithTreeMenuVisible(sysColumn));
    }


    @PostMapping("/findById")
    @ApiOperation(value = "查询详情", response = SysColumn.class)
    public R findById(@RequestParam("id") @ApiParam(value = "序号") Integer id) {
        SysColumn sysColumn = service.getById(id);
        SysTemplateStyle sysTemplateStyle = styleService.getById(sysColumn.getListStyleId());

        if (sysTemplateStyle.getPath() != null) {
            sysColumn.setPath(sysTemplateStyle.getPath());
        }

        return R.success(sysColumn);
    }

    @NoRepeatSubmit
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = SysColumn.class)
    public R save(@RequestBody @Valid SysColumn sysColumn) {
        QueryWrapper<SysColumn> queryWrapper = new QueryWrapper<SysColumn>();
        queryWrapper.eq("father_id", sysColumn.getFatherId());
        Integer count = service.count(queryWrapper);
        sysColumn.setSort(count + 1);
        boolean addState = service.save(sysColumn);
        return addState ? R.success(sysColumn.getId()) : R.fail("新增失败");
    }

    @PostMapping("/update")
    @ApiOperation(value = "修改", response = SysColumn.class)
    public R update(@RequestBody SysColumn sysColumn) {
        boolean updateState = service.updateById(sysColumn);
        return updateState ? R.success() : R.fail("编辑失败");
    }
    @NoRepeatSubmit
    @PostMapping("/delete")
    @ApiOperation(value = "删除", response = SysContent.class)
    public R delete(@ApiParam(name = "id", value = "主键", required = true) @RequestParam Integer id) {
        UpdateWrapper<SysFilesEntity> filesEntityUpdateWrapper = new UpdateWrapper<>();
        filesEntityUpdateWrapper.eq("quote_id",id);
        filesEntityUpdateWrapper.eq("quote_type",1);
        filesEntityUpdateWrapper.set("is_del",1);
        sysFilesService.update(filesEntityUpdateWrapper);

        boolean delState = service.removeById(id);

        QueryWrapper<SysContent> queryWrapper = new QueryWrapper<>();
        queryWrapper.in("column_id", id);
        //删除栏目后删除栏目下的文章
        List<SysContent> contentId = contentService.list(queryWrapper);
        contentService.removeByIds(contentId);

        return delState ? R.success() : R.fail("删除失败");
    }
    @NoRepeatSubmit
    @PostMapping("/batchDeletion")
    @ApiOperation(value = "批量删除栏目", response = SysColumn.class)
    public R batchDeletion(@ApiParam(name = "ids", value = "主键", required = true) @RequestParam List<Integer> ids) {
        for (Integer id : ids) {
            UpdateWrapper<SysFilesEntity> filesEntityUpdateWrapper = new UpdateWrapper<>();
            filesEntityUpdateWrapper.eq("quote_id",id);
            filesEntityUpdateWrapper.eq("quote_type",1);
            filesEntityUpdateWrapper.set("is_del",1);
            sysFilesService.update(filesEntityUpdateWrapper);
        }

        boolean delState = service.removeByIds(ids);
        QueryWrapper<SysContent> queryWrapper = new QueryWrapper<>();
        queryWrapper.in("column_id", ids);
        //删除栏目后删除栏目下的文章
        contentService.remove(queryWrapper);
        return delState ? R.success() : R.fail("删除失败");
    }

    @PostMapping("/sameLevelJudgment")
    @ApiOperation(value = "同级判重", response = ColumnWeightReqVO.class)
    public R sameLevelJudgment(@RequestBody @Valid ColumnWeightReqVO sysColumn) {
        return service.sameLevelJudgment(sysColumn) ? R.success() : R.fail("同级下已存在重复栏目!");
    }

    @PostMapping("/sortByColumn")
    @ApiOperation(value = "栏目排序(依据id更改)", response = SysColumn.class)
    public R sortByColumn(@RequestBody List<SortColumnRespVO> sortColumnRespVOList) {
        for (SortColumnRespVO sort : sortColumnRespVOList) {
            SysColumn sysColumn = new SysColumn();
            BeanUtils.copyProperties(sort, sysColumn);
            service.updateById(sysColumn);
        }

        return R.success();
    }

    @ApiOperation("获取一级下的子级栏目")
    @PostMapping("/getsTheSubColumn")
    public R getsTheSubColumn(Integer id) {
        String ids = this.getIds(id);
        return service.getsTheSubColumn(id, ids);

    }


    @ApiOperation("获取某层级下的子级栏目")
    @PostMapping("/getsSublevelColumnsUnderALevel")
    public R getsSublevelColumnsUnderALevel(Integer id) {
        String ids = this.getIds(id);
        return service.getsTheSubColumn(id, ids);

    }


    public String getIds(Integer id) {
        //1 创建list集合，用于封装所有删除菜单id值
        List<Integer> idList = new ArrayList<>();
        //2 向idList集合设置删除菜单id
        this.selectCategoryChildById(id + "", idList);//找到当前菜单的子菜单  把结果id封装到idlist里面去
        //把当前id封装到list里面
        idList.add(id);//现在把当前id封装进去  之前都是子菜单的id
        String str = "";
        for (Integer idstr : idList) {
            str += idstr + ",";
        }
        String ids = str.substring(0, str.length() - 1);
        return ids;
    }

    public void selectCategoryChildById(String id, List<Integer> idList) {
        //查询菜单里面子菜单id
        QueryWrapper<SysColumn> wrapper = new QueryWrapper<SysColumn>();
        wrapper.eq("father_id", id);
        wrapper.eq("deleted", Constant.DATA_NOT_DELETED);
        wrapper.select("id");//我们只想查询id  所以只需要查询指定列的值
        List<SysColumn> childIdList = service.list(wrapper);//当前菜单的所有子菜单
        //把childIdList里面菜单id值获取出来，封装idList里面，做递归查询
        childIdList.stream().forEach(item -> {//遍历集合得到每一个对象item
            //封装idList里面
            idList.add(item.getId());
            //递归查询
            this.selectCategoryChildById(item.getId() + "", idList);
        });
    }


    @ApiOperation("获取一级下的子级栏目以及下的全部文章标签")
    @PostMapping("/getTheFullArticleByColumn")
    public R getTheFullArticleByColumn(@ApiParam(name = "id", value = "一级栏目id", required = true) @RequestParam Integer id) {
        String ids = this.getIds(id);
        return contentService.getTheFullArticleByColumn(ids);
    }


    @ApiOperation("获取子级栏目id")
    @PostMapping("/getsTheChildColumnId")
    public R getsTheSublevelColumnIdOfTheNextLevel(@ApiParam(name = "id", value = "一级栏目id", required = true) @RequestParam Integer id) {
        //1 创建list集合，用于封装所有删除菜单id值
        List<Integer> idList = new ArrayList<>();
        //2 向idList集合设置删除菜单id
        this.selectCategoryChildById(id + "", idList);//找到当前菜单的子菜单  把结果id封装到idlist里面去
        //把当前id封装到list里面
        idList.add(id);//现在把当前id封装进去  之前都是子菜单的id
        return R.success(idList);

    }

    @ApiOperation("某一级查全部")
    @PostMapping("/oneLevelChecksThemAll")
    public R oneLevelChecksThemAll(@ApiParam(name = "id", value = "栏目id", required = true) @RequestParam Integer id,
                                   @ApiParam(name = "isSort", value = "判断是否为排序接口调用(1为排序接口调用 0我栏目管理列表调用)", required = true) @RequestParam Integer isSort) {

        Integer pid = service.oneLevelChecksThemAll(id);
        String ids = this.getIds(pid);
        return service.getSubColumn(pid, ids,isSort);
    }


    /**
     * 查询栏目下的文章(若选中栏目与子级全部栏目类型一致返回全部文章，反之查询选中栏目下的文章)
     * @param columnId
     * @return
     */
    @ApiOperation("查询栏目下的文章(若选中栏目与子级全部栏目类型一致返回全部文章，反之查询选中栏目下的文章)")
    @PostMapping("/queryArticlesByColumnType")
    public R queryArticlesByColumnType(@ApiParam(name = "columnId", value = "栏目id", required = true) @RequestParam Integer columnId) {
        String ids = this.getIds(columnId);
        return service.queryArticlesByColumnType(ids,columnId);
    }

}

