package com.huoran.iasf.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huoran.iasf.entity.SysColumn;
import com.huoran.iasf.entity.SysContentFile;
import com.huoran.iasf.entity.SysFilesEntity;
import com.huoran.iasf.service.SysColumnService;
import com.huoran.iasf.service.SysContentFileService;
import com.huoran.iasf.service.SysFilesService;
import com.huoran.iasf.vo.req.ContentHeavyTitleReqVO;
import com.huoran.iasf.vo.req.ContentReq;
import com.huoran.iasf.vo.req.PageContentReqVO;
import com.huoran.iasf.vo.resp.PageContentRespVO;
import io.swagger.annotations.*;
import com.huoran.iasf.common.utils.R;
import org.apache.ibatis.annotations.Update;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.Api;
import org.springframework.web.bind.annotation.RequestParam;
import io.swagger.annotations.ApiOperation;
import com.huoran.iasf.service.SysContentService;
import com.huoran.iasf.entity.SysContent;

import javax.validation.Valid;
import java.util.List;


/**
 * @描述：文章管理控制类
 * @作者: Rong
 * @日期: 2022-08-05
 */
@RestController
@RequestMapping("/sysContent")
@Api(value = "文章管理:SysContentController", tags = "R-文章管理")
public class SysContentController {

    @Autowired
    public SysContentService service;
    @Autowired
    public SysColumnService columnService;

    @Autowired
    public SysContentFileService fileService;

    @Autowired
    public SysFilesService sysFilesService;



    @PostMapping("/pagingQuery")
    @ApiOperation(value = "分页查询文章列表", response = PageContentRespVO.class)
    public R pagingQuery(@RequestBody @Valid @ApiParam(name = "分页查询参数", value = "传入json格式", required = true) PageContentReqVO sysContent) {
        return service.articlePaginationList(sysContent);
    }


    @PostMapping("/findById")
    @ApiOperation(value = "查询详情", response = SysContent.class)
    public R findById(@ApiParam(name = "id", value = "主键", required = true) @RequestParam Integer id) {
        SysContent sysContent = service.getById(id);

        SysColumn sysColumn = columnService.getById(sysContent.getColumnId());
        if (sysColumn.getColumnName() != null) {
            sysContent.setColumnName(sysColumn.getColumnName());
        }
        List<SysContentFile> fileList = fileService.getFileByContentId(id);
        sysContent.setFileList(fileList);

        return R.success(sysContent);
    }

    @PostMapping("/save")
    @ApiOperation(value = "新增", response = SysContent.class)
    public R save(@RequestBody @Valid @ApiParam(name = "文章管理对象", value = "传入json格式", required = true) SysContent sysContent) {
        boolean addState = service.save(sysContent);
        return addState ? R.success(sysContent.getId()) : R.fail("新增失败");
    }


    @PostMapping("/update")
    @ApiOperation(value = "修改", response = SysContent.class)
    public R update(@RequestBody @ApiParam(name = "文章管理对象", value = "传入json格式", required = true) SysContent sysContent) {
        boolean updateState = service.updateById(sysContent);
        return updateState ? R.success() : R.fail("编辑失败");
    }


    @PostMapping("/delete")
    @ApiOperation(value = "删除", response = SysContent.class)
    public R delete(@ApiParam(name = "id", value = "主键", required = true) @RequestParam Integer id) {
        UpdateWrapper<SysFilesEntity> queryWrapper = new UpdateWrapper<>();
        queryWrapper.eq("quote_id",id);
        queryWrapper.eq("quote_type",0);
        queryWrapper.set("is_del",1);
        sysFilesService.update(queryWrapper);
        boolean delState = service.removeById(id);
        return delState ? R.success() : R.fail("删除失败");
    }


    @PostMapping("/batchDeletion")
    @ApiOperation(value = "批量删除文章", response = SysContent.class)
    public R batchDeletion(@ApiParam(name = "ids", value = "主键", required = true) @RequestParam List<Integer> ids) {
        for (Integer id : ids) {
            UpdateWrapper<SysFilesEntity> queryWrapper = new UpdateWrapper<>();
            queryWrapper.eq("quote_id",id);
            queryWrapper.eq("quote_type",0);
            queryWrapper.set("is_del",1);
            sysFilesService.update(queryWrapper);
        }
        boolean delState = service.removeByIds(ids);
        return delState ? R.success() : R.fail("删除失败");
    }

    @PostMapping("/checkIfTheTitleIsRepeat")
    @ApiOperation(value = "标题判重——只对已发布的判重(新增，编辑，点击发布时候都要调用判断))", response = ContentHeavyTitleReqVO.class)
    public R checkIfTheTitleIsRepeat(@RequestBody @Valid ContentHeavyTitleReqVO content) {
        return service.checkIfTheTitleIsRepeat(content) ? R.success() : R.fail("该标题已重复!");
    }

    @PostMapping("/newlyPublishedArticles")
    @ApiOperation(value = "站点最新发布的文章", response = PageContentReqVO.class)
    public R newlyPublishedArticles(@RequestBody @Valid PageContentReqVO content) {
        return service.newlyPublishedArticles(content);
    }


    /*查询已发布的、启用了的文章列表接口*/
    @PostMapping("/publishedEnabledArticles")
    @ApiOperation(value = "查询已发布的、启用了的文章列表", response = PageContentReqVO.class)
    public R publishedEnabledArticles() {
        return service.publishedEnabledArticles();
    }


    /**
     * 获取栏目下的文章
     *
     * @param pageReq
     * @return
     */
    @PostMapping("/getColumnArticles")
    @ApiOperation(value = "获取栏目下的文章", response = SysContent.class)
    public R getColumnArticles(@RequestBody @ApiParam(name = "文章管理对象", value = "传入json格式", required = true) ContentReq pageReq) {
        IPage page = new Page(pageReq.getPageNum(), pageReq.getPageSize());
        QueryWrapper<SysContent> queryWrapper = new QueryWrapper<>();
        queryWrapper.in("column_id", pageReq.getColumnIds());
        IPage<SysContent> iPage = service.page(page, queryWrapper);
        return R.success(iPage);
    }


    @PostMapping("/articleEnableOrDisable")
    @ApiOperation(value = "文章启用禁用", response = SysContent.class)
    public R articleEnableOrDisable(@ApiParam(name = "id", value = "文章id", required = true) @RequestParam Integer id, @ApiParam(name = "isDisable", value = "是否禁用(0默认，0启用 1禁用)", required = true) @RequestParam Integer isDisable) {
        UpdateWrapper<SysContent> updateWrapper = new UpdateWrapper<>();
        updateWrapper.set("is_disable", isDisable);
        updateWrapper.eq("id", id);
        boolean ret = service.update(updateWrapper);
        return ret ? R.success() : R.fail("禁用/启用失败");
    }

    @PostMapping("/articlePreview")
    @ApiOperation(value = "增加文章浏览量(点击一次算一次)", response = SysContent.class)
    public R articlePreview(@ApiParam(name = "contentId", value = "文章id", required = true) @RequestParam Integer contentId) {
        return R.success(service.statisticsOfPageViews(contentId));

    }


    @PostMapping("/hotContent")
    @ApiOperation(value = "热点内容", response = SysContent.class)
    public R hotContent(@ApiParam(name = "siteId", value = "站点id", required = true) @RequestParam Integer siteId) {
        return R.success(service.hotContent(siteId));

    }

    @PostMapping("/siteSearchArticles")
    @ApiOperation(value = "站点搜索文章", response = SysContent.class)
    public R siteSearchArticles(@RequestBody PageContentReqVO req) {
        return service.siteSearchArticles(req);

    }
}

