package com.huoran.iasf.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huoran.iasf.common.utils.R;
import com.huoran.iasf.entity.SysContentClassification;
import com.huoran.iasf.entity.SysContentLabel;
import com.huoran.iasf.service.SysContentLabelService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.apache.commons.lang.StringUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.Api;
import org.springframework.web.bind.annotation.RequestParam;
import io.swagger.annotations.ApiOperation;

import javax.validation.Valid;
import java.util.List;


/**
 * @描述：文章主题标签控制类
 * @作者: Rong
 * @日期: 2022-11-08
 */
@RestController
@RequestMapping("/content/label")
@Api(value = "文章主题标签:SysContentLabelController", tags = "R-文章主题标签")
public class SysContentLabelController {

    @Autowired
    public SysContentLabelService service;


    @PostMapping("/queryAllArticleSubjectTags")
    @ApiOperation(value = "查询全部文章主题标签", response = SysContentLabel.class)
    public R queryAllArticleSubjectTags(@ApiParam(name = "siteId", value = "站点id", required = true) @RequestParam Integer siteId) {
        List<SysContentLabel> list = service.list(new QueryWrapper<SysContentLabel>().eq("site_id", siteId));
        return R.success(list);
    }


    @PostMapping("/findById")
    @ApiOperation(value = "查询详情", response = SysContentLabel.class)
    public R findById(@ApiParam(name = "id", value = "主键", required = true) @RequestParam Integer id) {
        SysContentLabel sysContentLabel = service.getById(id);
        return R.success(sysContentLabel);
    }


    @PostMapping("/save")
    @ApiOperation(value = "新增", response = SysContentLabel.class)
    public R save(@RequestBody @Valid @ApiParam(name = "文章主题标签对象", value = "传入json格式", required = true) SysContentLabel sysContentLabel) {
        boolean addState = service.save(sysContentLabel);
        return addState ? R.success() : R.fail("新增失败");
    }


    @PostMapping("/checkForHeavy")
    @ApiOperation(value = "标签校验判重", response = SysContentLabel.class)
    public R checkForHeavy(@ApiParam(name = "siteId", value = "站点id", required = true) @RequestParam Integer siteId,
                           @ApiParam(name = "labelName", value = "标签名称", required = true) @RequestParam String labelName,
                           @ApiParam(name = "labelId", value = "标签id(新增不传，编辑传)", required = false) @RequestParam Integer labelId) {

        QueryWrapper<SysContentLabel> queryWrapper = new QueryWrapper<SysContentLabel>().eq("site_id", siteId).eq("label_name", labelName);

        //id不得空表示编辑校验
        if (labelId != null) {
            queryWrapper.last(" and id != " + labelId);
        }
        SysContentLabel contentLabel = service.getOne(queryWrapper);
        if (contentLabel != null) {
            return R.fail("当前标签名称已存在!");
        }
        return R.success();

    }


    @PostMapping("/update")
    @ApiOperation(value = "修改", response = SysContentLabel.class)
    public R update(@RequestBody @ApiParam(name = "文章主题标签对象", value = "传入json格式", required = true) SysContentLabel sysContentLabel) {
        boolean updateState = service.updateById(sysContentLabel);
        return updateState ? R.success() : R.fail("编辑失败");
    }


    @PostMapping("/delete")
    @ApiOperation(value = "删除", response = SysContentLabel.class)
    public R delete(@ApiParam(name = "id", value = "主键", required = true) @RequestParam Integer id) {
        boolean delState = service.removeById(id);
        return delState ? R.success() : R.fail("删除失败");
    }

    @PostMapping("/batchDeletion")
    @ApiOperation(value = "批量删除", response = SysContentLabel.class)
    public R batchDeletion(@ApiParam(name = "id", value = "主键", required = true) @RequestParam List<Integer> ids) {
        boolean delState = service.removeByIds(ids);
        return delState ? R.success() : R.fail("删除失败");
    }
}

