package com.huoran.iasf.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huoran.iasf.common.utils.Constant;
import com.huoran.iasf.common.utils.R;
import com.huoran.iasf.entity.SysContent;
import com.huoran.iasf.mapper.SysContentMapper;
import com.huoran.iasf.service.SysContentService;
import com.huoran.iasf.vo.req.ContentHeavyTitleReqVO;
import com.huoran.iasf.vo.req.PageContentReqVO;
import com.huoran.iasf.vo.resp.PageContentRespVO;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.*;

/**
 * @描述：文章管理 服务类
 * @作者: Rong
 * @日期: 2022-08-05
 */
@Service
public class SysContentServiceImpl extends ServiceImpl<SysContentMapper, SysContent> implements SysContentService {

    @Autowired
    private SysContentMapper mapper;

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Override
    public boolean checkIfTheTitleIsRepeat(ContentHeavyTitleReqVO content) {
        //只对已发布的标题判重
        QueryWrapper<SysContent> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("title", content.getTitle());
        queryWrapper.eq("is_release", Constant.ARTICLE_PUBLISHED);
        queryWrapper.eq("site_id", content.getSiteId());
        SysContent sysContent = mapper.selectOne(queryWrapper);
        if (sysContent != null) {
            if (content.getId() != null) {
                //判断为编辑情况下，如果编辑的id与查询出来的一致不提示
                if (content.getId() == content.getId()) {
                    return true;
                }
            }

            return false;
        }
        return true;
    }

    @Override
    public R articlePaginationList(PageContentReqVO reqVO) {
        Page<PageContentRespVO> page = new Page<PageContentRespVO>(reqVO.getPageNum(), reqVO.getPageSize());
        IPage<PageContentRespVO> pageList = baseMapper.articlePaginationList(page, reqVO);
        return R.success(pageList);
    }

    @Override
    public R newlyPublishedArticles(PageContentReqVO reqVO) {
        Page<PageContentRespVO> page = new Page<PageContentRespVO>(reqVO.getPageNum(), reqVO.getPageSize());
        IPage<PageContentRespVO> pageList = baseMapper.getPublishedArticles(page, reqVO);
        return R.success(pageList);
    }

    @Override
    public R publishedEnabledArticles() {
        //查询已发布的、启用了的文章列表接
        QueryWrapper<SysContent> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("is_release", Constant.ARTICLE_PUBLISHED);
        queryWrapper.eq("template_status", Constant.TEMPLATE_STATUS_ENABLED);
        List<SysContent> sysContentList = mapper.selectList(queryWrapper);
        return R.success(sysContentList);

    }

    @Override
    public R getTheFullArticleByColumn(String ids) {
        return R.success(mapper.useTheColumnToGetTagsForTheFullArticle(ids));
    }

    @Override
    public Integer statisticsOfPageViews(Integer id) {

        String key = "preview:contentId:" + id;
        //查看缓存是否有数据
        String returnValue = redisTemplate.opsForValue().get(key);
        if (returnValue == null) {
            returnValue = "0";
        }
        returnValue = Integer.valueOf(returnValue) + 1 + "";
        //保存到缓存中
        redisTemplate.opsForValue().set(key, returnValue + "");

        SysContent sysContent = new SysContent();
        sysContent.setId(id);
        sysContent.setTotalBrowsing(Integer.valueOf(returnValue));
        mapper.updateById(sysContent);

        return Integer.valueOf(returnValue);
    }

    @Override
    public List<SysContent> hotContent(Integer siteId) {
        QueryWrapper<SysContent> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("deleted", Constant.DATA_NOT_DELETED);
        queryWrapper.eq("site_id", siteId);
        queryWrapper.last(" ORDER BY total_browsing desc LIMIT 0,5");

        List<SysContent> contentList = baseMapper.selectList(queryWrapper);
        return contentList;
    }

    @Override
    public R siteSearchArticles(PageContentReqVO reqVO) {
        Page<SysContent> page = new Page<SysContent>(reqVO.getPageNum(), reqVO.getPageSize());
        IPage<SysContent> pageList = baseMapper.siteSearchArticles(page, reqVO);
        return R.success(pageList);
    }


}




